carrot.backends — Carrot v0.5.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Carrot v0.5.0 documentation »
- API Reference »

# carrot.backends

Working with Backends.

`carrot.backends.` `get_backend_cls`(backend)

  Get backend class by name.

  If the name does not include “`.`” (is not fully qualified), `"carrot.backends."` will be prepended to the name. e.g. `"pyqueue"` becomes `"carrot.backends.pyqueue"`.

`carrot.backends.` `get_default_backend_cls`
  class `carrot.backends.` `DefaultBackend`
    The default backend class. This is the class specified in `DEFAULT_BACKEND`.

### Navigation

- index
- modules |
- next |
- previous |
- Carrot v0.5.0 documentation »
- API Reference »